@@ -1,6 +1,6 @@
 /************************************************************************
- * cmds.c -- part of rpncalc.c						*
- *									*
+ * cmds.c -- part of rpncalc.c                                          *
+ *                                                                      *
  * Refer to rpncalc.c for copyrights and license permissions.           *
  ************************************************************************/
 
@@ -57,18 +57,12 @@
 #include <float.h>
 #include <errno.h>
 
-#include "config.h"
-
 #include "stack.h"
 #include "cmds.h"
 
-#ifdef HAVE_GETTEXT
 #include <libintl.h>
 
 #define  _(String) gettext(String)
-#else
-#define  _(String) (String)
-#endif
 
 extern struct cmd cmdtab[];
 
@@ -76,11 +70,11 @@ extern int noofcmds;
 extern int done;
 extern int pushtostack;
 
-struct cnst consttab[] = 
+struct cnst consttab[] =
 {
   { "e"   , M_E    , "Euler's constant"     },
   { "minr", FLT_MIN, "smallest real number" },
-  { "maxr", FLT_MAX, "largest real number"  }, 
+  { "maxr", FLT_MAX, "largest real number"  },
   { "pi"  , M_PI   , "the constant pi"      }
 };
 
@@ -94,7 +88,7 @@ int cmdcmp(const void *f1, const void *f2)
 /* (String-)Compare the two function names, cf. iX 11/95 p 212 */
 {
   return strcmp(((const struct cmd *)f1)->fname,
-		((const struct cmd *)f2)->fname);
+                ((const struct cmd *)f2)->fname);
 }
 
 int varcmp(const void *f1, const void *f2)
@@ -105,7 +99,7 @@ int varcmp(const void *f1, const void *f2)
   else if ((f1 != NULL) && (f2 == NULL)) return -1;
   else
     return strcmp(((const struct var *)f1)->vname,
-		  ((const struct var *)f2)->vname);
+                  ((const struct var *)f2)->vname);
 }
 
 /* -------------------------------------------------------- unary operators */
@@ -120,19 +114,19 @@ double chs(double f)   { return -f; }
 
 double sqr(double f)   { return f * f; }
 
-double sign(double f)   { 
+double sign(double f)   {
   double s;
   if      (f <  0.0) s=-1.0;
   else if (f == 0.0) s= 0.0;
   else               s=+1.0;
-  
+
   return s;
 }
 
 double inv(double f)
 {
   if (f != 0)   res = 1 / f;
-  else          { res = HUGE_VAL; errno = ERANGE; }	    
+  else          { res = HUGE_VAL; errno = ERANGE; }
   return res;
 }
 
@@ -152,7 +146,7 @@ double fact(double d)
     pushtostack=0;
   } else if (n == d) {
     if ((n == 0) || (n == 1)) {
-      res = 1; 
+      res = 1;
     } else {
       res = 1;
       for (i = n; i > 1; i--) res *= i;
@@ -184,7 +178,7 @@ double multiply(double f1, double f2) { return f1 * f2; }
 double divide(double n, double d)
 {
   if (d != 0) res = n / d;
-  else      { res = HUGE_VAL; errno = ERANGE; }	    
+  else      { res = HUGE_VAL; errno = ERANGE; }
   return res;
 }
 
@@ -199,18 +193,18 @@ double idiv(double dn, double dd)
   {
     if (d != 0)
     {
-      quotrem = ldiv(n,d); 
+      quotrem = ldiv(n,d);
       res = (double)quotrem.quot;
     }
     else
-    { 
-      res = HUGE_VAL; errno = ERANGE; 
-    }	 
+    {
+      res = HUGE_VAL; errno = ERANGE;
+    }
   }
   else
-  { 
+  {
     errno = EOVERFLOW; pushtostack=0;
-  }	    
+  }
   return res;
 }
 
@@ -224,17 +218,17 @@ double mod(double dn, double dd)
    if (d != 0)
    {
      quotrem = ldiv(n,d);
-     res = (double)quotrem.rem;  
+     res = (double)quotrem.rem;
    }
    else
-   { 
-     res = HUGE_VAL; errno = ERANGE; 
-   }	    
+   {
+     res = HUGE_VAL; errno = ERANGE;
+   }
  }
  else
- {	
+ {
    errno = EOVERFLOW; pushtostack=0;
- }	    
+ }
  return res;
 }
 
@@ -242,9 +236,9 @@ double mod(double dn, double dd)
 long int stein(double d1, double d2)
 {
   long int n1, n2;
-  long int d;				 /* difference */
-  long int c;				 /* c: shift-count (see below) */
-  long int t;				 /* temporary */
+  long int d;                            /* difference */
+  long int c;                            /* c: shift-count (see below) */
+  long int t;                            /* temporary */
 
   c = 0; n1=(long int)d1; n2=(long int)d2;
   /* both integers are even; shift them until one gets odd. */
@@ -256,7 +250,7 @@ long int stein(double d1, double d2)
   do
   {
     if ((n2 & 1) == 0) { t = n1; n1 = n2; n2 = t; }
-    
+
     while ((n1 & 1) == 0)
       n1 >>= 1;
 
@@ -284,7 +278,7 @@ double gcd(double dn, double dd)
   }
   else
   {
-    errno = EOVERFLOW;	
+    errno = EOVERFLOW;
     pushtostack = 0;
   }
   return res;
@@ -371,9 +365,9 @@ double help(struct cmd *f)
 
     if (f->pushrestostack) {
       if (f->argno == 1)
-	printf(_(" and takes 1 argument"));
+        printf(_(" and takes 1 argument"));
       else
-	printf(_(" and takes %d arguments"),f->argno);
+        printf(_(" and takes %d arguments"),f->argno);
     }
     printf(".\n");
   } else {
